System messages
---------------

The main distinguish between messages that "system": 

* Bordered with asterix
* Used as information for chat participants
* Can be displayed only for one user

System messages shows as a result of chat events:

* New chat was created and "invitation code" was generated
* Uses joins to chat
* Chat was closed by participant
* Error appears (validation, internal chat errors etc.)

Message has structure bellow:

* Border on the top and button with asterix
* Message text
